# Class Diagram Generator

A python library for generating a class diagram based on source code.

Created for: https://github.com/RokasPuzonas/ktu-oop-report-generator

## Installation
```
pip install class-diagram-generator
```
